# Olli

[![PyPI version fury.io](https://badge.fury.io/py/olli.svg)](https://pypi.python.org/pypi/olli/)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/olli.svg)](https://pypi.python.org/pypi/olli/)
[![GitHub license](https://img.shields.io/github/license/python-discord/olli.svg)](https://github.com/python-discord/olli/blob/main/LICENSE)

Olli searches your Loki logs and relays matching terms to Discord. Please read the [documentation](https://python-discord.github.io/olli/) to get started.

- [Documentation](https://python-discord.github.io/olli/)
- [Docker Image](https://ghcr.io/python-discord/olli)

## Contributing

Please open an issue before contributing features to discuss implementation.

## License

Olli is licensed under MIT.
